# translatemib.mak
#  RBLandau 20070909
# Translate the XML group files into MIB fragments
# using Xalan

# Directory layout
SRC = ..
XSL = .
DST = ./mib
PERL = c:/perl/bin
MIBSRC = ../../mib

# Command to run Xalan to do the translation
PGMDIR = /cygdrive/c
PGM = $(PGMDIR)/run_xalan.sh

# Latest versions of the XML groups
VER_ALERT = 01
VER_BUTTON = 03
VER_DISPLAYCAPABILITY = 09a
VER_DISPLAYSETTING = xx
VER_GENERAL = xx
VER_INTERFACE = 03
VER_INTERLOCK = 13
VER_LIGHTSOURCE = 07
VER_LOCALIZATION = 03b
VER_POWERSTATE = 09a
VER_SYSTEMCONTROLLER = 04a
VER_THERMALFAN = 09b
VER_THERMALFILTER = xx
VER_THERMALSENSOR = xx
VER_THERMALSWITCH = xx

# Latest versions of the XSL translation programs
VER_TABLES = 07
VER_PROPS = 16
VER_ENUMS = 05
VER_ASSEMBLE = 01
VER_SKELETON = 01

# Now paste these together into a full filename
TABLES = tables$(VER_TABLES).xsl
PROPS = props$(VER_PROPS).xsl
ENUMS = enumtc$(VER_ENUMS).xsl

# Targets
all :   target_translators  \
        target_alert        \
        target_button       \
        target_displaycapability    \
        target_interface    \
        target_interlock    \
        target_lightsource  \
        target_localization \
        target_powerstate   \
        target_systemcontroller   \
        target_thermalfan   \
        
#

# A target for the XSL files themselves
target_translators : $(TABLES) $(PROPS) $(ENUMS) 

# Targets for the individual groups

# A l e r t 
target_alert :      $(DST)/alert.tables.mib    \
                    $(DST)/alert.props.mib     \
                    $(DST)/alert.enums.mib     \
                    target_translators
$(DST)/alert.tables.mib : $(SRC)/Alert_v$(VER_ALERT).xml $(TABLES)
	$(PGM) $< $(XSL)/$(TABLES) $(DST)/alert.tables.mib
$(DST)/alert.props.mib : $(SRC)/Alert_v$(VER_ALERT).xml $(PROPS)
	$(PGM) $< $(XSL)/$(PROPS) $(DST)/alert.props.mib
$(DST)/alert.enums.mib : $(SRC)/Alert_v$(VER_ALERT).xml $(ENUMS)
	$(PGM) $< $(XSL)/$(ENUMS) $(DST)/alert.enums.mib

# B u t t o n
target_button :     $(DST)/button.tables.mib    \
                    $(DST)/button.props.mib     \
                    $(DST)/button.enums.mib     \
                    target_translators
$(DST)/button.tables.mib : $(SRC)/Button_v$(VER_BUTTON).xml $(TABLES)
	$(PGM) $< $(XSL)/$(TABLES) $(DST)/button.tables.mib
$(DST)/button.props.mib : $(SRC)/Button_v$(VER_BUTTON).xml $(PROPS)
	$(PGM) $< $(XSL)/$(PROPS) $(DST)/button.props.mib
$(DST)/button.enums.mib : $(SRC)/Button_v$(VER_BUTTON).xml $(ENUMS)
	$(PGM) $< $(XSL)/$(ENUMS) $(DST)/button.enums.mib

# D i s p l a y C a p a b i l i t y 
target_displaycapability :  $(DST)/displaycapability.tables.mib \
                            $(DST)/displaycapability.props.mib  \
                            $(DST)/displaycapability.enums.mib  \
                            target_translators
SRCFILE = $(SRC)/DisplayCapability_v$(VER_DISPLAYCAPABILITY).xml
DSTFILE = $(DST)/displaycapability
$(DSTFILE).tables.mib : $(SRCFILE) $(TABLES)
	$(PGM) $< $(XSL)/$(TABLES) $(DSTFILE).tables.mib
$(DSTFILE).props.mib : $(SRCFILE) $(PROPS)
	$(PGM) $< $(XSL)/$(PROPS) $(DSTFILE).props.mib
$(DSTFILE).enums.mib : $(SRCFILE) $(ENUMS)
	$(PGM) $< $(XSL)/$(ENUMS) $(DSTFILE).enums.mib

# I n t e r f a c e 
target_interface :  $(DST)/interface.tables.mib \
                    $(DST)/interface.props.mib  \
                    $(DST)/interface.enums.mib  \
                    target_translators
$(DST)/interface.tables.mib : $(SRC)/Interface_v$(VER_INTERFACE).xml $(TABLES)
	$(PGM) $< $(XSL)/$(TABLES) $(DST)/interface.tables.mib
$(DST)/interface.props.mib : $(SRC)/Interface_v$(VER_INTERFACE).xml $(PROPS)
	$(PGM) $< $(XSL)/$(PROPS) $(DST)/interface.props.mib
$(DST)/interface.enums.mib : $(SRC)/Interface_v$(VER_INTERFACE).xml $(ENUMS)
	$(PGM) $< $(XSL)/$(ENUMS) $(DST)/interface.enums.mib

# I n t e r l o c k 
target_interlock :  $(DST)/interlock.tables.mib \
                    $(DST)/interlock.props.mib  \
                    $(DST)/interlock.enums.mib  \
                    target_translators
$(DST)/interlock.tables.mib : $(SRC)/Interlock_v$(VER_INTERLOCK).xml $(TABLES)
	$(PGM) $< $(XSL)/$(TABLES) $(DST)/interlock.tables.mib
$(DST)/interlock.props.mib : $(SRC)/Interlock_v$(VER_INTERLOCK).xml $(PROPS)
	$(PGM) $< $(XSL)/$(PROPS) $(DST)/interlock.props.mib
$(DST)/interlock.enums.mib : $(SRC)/Interlock_v$(VER_INTERLOCK).xml $(ENUMS)
	$(PGM) $< $(XSL)/$(ENUMS) $(DST)/interlock.enums.mib

# L i g h t S o u r c e 
target_lightsource :  $(DST)/lightsource.tables.mib \
                      $(DST)/lightsource.props.mib  \
                      $(DST)/lightsource.enums.mib  \
                      target_translators
$(DST)/lightsource.tables.mib : $(SRC)/LightSource_v$(VER_LIGHTSOURCE).xml $(TABLES)
	$(PGM) $< $(XSL)/$(TABLES) $(DST)/lightsource.tables.mib
$(DST)/lightsource.props.mib : $(SRC)/LightSource_v$(VER_LIGHTSOURCE).xml $(PROPS)
	$(PGM) $< $(XSL)/$(PROPS) $(DST)/lightsource.props.mib
$(DST)/lightsource.enums.mib : $(SRC)/LightSource_v$(VER_LIGHTSOURCE).xml $(ENUMS)
	$(PGM) $< $(XSL)/$(ENUMS) $(DST)/lightsource.enums.mib

# L o c a l i z a t i o n 
target_localization :  $(DST)/localization.tables.mib \
                       $(DST)/localization.props.mib  \
                       $(DST)/localization.enums.mib  \
                       target_translators
$(DST)/localization.tables.mib : $(SRC)/Localization_v$(VER_LOCALIZATION).xml $(TABLES)
	$(PGM) $< $(XSL)/$(TABLES) $(DST)/localization.tables.mib
$(DST)/localization.props.mib : $(SRC)/Localization_v$(VER_LOCALIZATION).xml $(PROPS)
	$(PGM) $< $(XSL)/$(PROPS) $(DST)/localization.props.mib
$(DST)/localization.enums.mib : $(SRC)/Localization_v$(VER_LOCALIZATION).xml $(ENUMS)
	$(PGM) $< $(XSL)/$(ENUMS) $(DST)/localization.enums.mib

# P o w e r S t a t e 
target_powerstate :     $(DST)/powerstate.tables.mib \
                        $(DST)/powerstate.props.mib  \
                        $(DST)/powerstate.enums.mib  \
                        target_translators
$(DST)/powerstate.tables.mib : $(SRC)/PowerState_v$(VER_POWERSTATE).xml $(TABLES)
	$(PGM) $< $(XSL)/$(TABLES) $(DST)/powerstate.tables.mib
$(DST)/powerstate.props.mib : $(SRC)/PowerState_v$(VER_POWERSTATE).xml $(PROPS)
	$(PGM) $< $(XSL)/$(PROPS) $(DST)/powerstate.props.mib
$(DST)/powerstate.enums.mib : $(SRC)/PowerState_v$(VER_POWERSTATE).xml $(ENUMS)
	$(PGM) $< $(XSL)/$(ENUMS) $(DST)/powerstate.enums.mib

# S y s t e m C o n t r o l l e r 
target_systemcontroller :     $(DST)/systemcontroller.tables.mib \
                        $(DST)/systemcontroller.props.mib  \
                        $(DST)/systemcontroller.enums.mib  \
                        target_translators
$(DST)/systemcontroller.tables.mib : $(SRC)/SystemController_v$(VER_SYSTEMCONTROLLER).xml $(TABLES)
	$(PGM) $< $(XSL)/$(TABLES) $(DST)/systemcontroller.tables.mib
$(DST)/systemcontroller.props.mib : $(SRC)/SystemController_v$(VER_SYSTEMCONTROLLER).xml $(PROPS)
	$(PGM) $< $(XSL)/$(PROPS) $(DST)/systemcontroller.props.mib
$(DST)/systemcontroller.enums.mib : $(SRC)/SystemController_v$(VER_SYSTEMCONTROLLER).xml $(ENUMS)
	$(PGM) $< $(XSL)/$(ENUMS) $(DST)/systemcontroller.enums.mib

# T h e r m a l F a n 
target_thermalfan :     $(DST)/thermalfan.tables.mib \
                        $(DST)/thermalfan.props.mib  \
                        $(DST)/thermalfan.enums.mib  \
                        target_translators
$(DST)/thermalfan.tables.mib : $(SRC)/ThermalFan_v$(VER_THERMALFAN).xml $(TABLES)
	$(PGM) $< $(XSL)/$(TABLES) $(DST)/thermalfan.tables.mib
$(DST)/thermalfan.props.mib : $(SRC)/ThermalFan_v$(VER_THERMALFAN).xml $(PROPS)
	$(PGM) $< $(XSL)/$(PROPS) $(DST)/thermalfan.props.mib
$(DST)/thermalfan.enums.mib : $(SRC)/ThermalFan_v$(VER_THERMALFAN).xml $(ENUMS)
	$(PGM) $< $(XSL)/$(ENUMS) $(DST)/thermalfan.enums.mib


clean : 
	ls $(DST)
	rm -f $(DST)/*.tables.mib $(DST)/*.props.mib $(DST)/*.enums.mib
	rm -f $(DST)/skel*.mib
	ls $(DST)

cleanskeleton : 
	rm -f $(DST)/skel*.mib


help :
	echo Makefile for Projector \& Display Management Working Group.
	echo Translate property group definitions from XML to MIB fragments.
	echo Version 0.4 2007/09/14


list : 
	echo Output files:
	ls $(DST)
	
listfull : 
	echo Output files:
	ls -l $(DST)


$(DST)/skeleton-in$(VER_SKELETON).mib : $(MIBSRC)/skeleton-in$(VER_SKELETON).mib
	cp $(MIBSRC)/skeleton-in$(VER_SKELETON).mib $(DST)/skeleton-in$(VER_SKELETON).mib

$(DST)/skeleton-out.mib :   $(DST)/skeleton-in$(VER_SKELETON).mib   \
                            $(XSL)/assemblefiles$(VER_ASSEMBLE).pl
	$(PERL)/perl.exe $(XSL)/assemblefiles$(VER_ASSEMBLE).pl     \
                     $(DST)/skeleton-in$(VER_SKELETON).mib       \
                     > $(DST)/skeleton-out.mib
	
assemble : all $(DST)/skeleton-out.mib


